@@ -1,6 +1,7 @@
 use std::io::prelude::*;
 
 use rayon::prelude::*;
+use snapbox::path::FileType;
 
 #[derive(Debug)]
 pub(crate) struct Runner {
@@ -22,15 +23,12 @@ impl Runner {
         &self,
         mode: &Mode,
         bins: &crate::BinRegistry,
-        substitutions: &crate::elide::Substitutions,
+        substitutions: &snapbox::Substitutions,
     ) {
-        let palette = crate::Palette::current();
+        let palette = snapbox::report::Palette::auto();
 
         if self.cases.is_empty() {
-            eprintln!(
-                "{}",
-                palette.warn.paint("There are no trycmd tests enabled yet")
-            );
+            eprintln!("{}", palette.warn("There are no trycmd tests enabled yet"));
         } else {
             let failures: Vec<_> = self
                 .cases
@@ -44,13 +42,13 @@ impl Runner {
                     results
                         .into_iter()
                         .filter_map(|s| {
-                            debug!("Case: {:#?}", s);
+                            snapbox::debug!("Case: {:#?}", s);
                             match s {
                                 Ok(status) => {
                                     let _ = writeln!(
                                         stderr,
                                         "{} {} ... {}",
-                                        palette.hint.paint("Testing"),
+                                        palette.hint("Testing"),
                                         status.name(),
                                         status.spawn.status.summary()
                                     );
@@ -64,9 +62,9 @@ impl Runner {
                                     let _ = writeln!(
                                         stderr,
                                         "{} {} ... {}",
-                                        palette.hint.paint("Testing"),
+                                        palette.hint("Testing"),
                                         status.name(),
-                                        palette.error.paint("failed"),
+                                        palette.error("failed"),
                                     );
                                     // Assuming `status` will print the newline
                                     let _ = write!(stderr, "{}", &status);
@@ -84,14 +82,12 @@ impl Runner {
                 let _ = writeln!(
                     stderr,
                     "{}",
-                    palette
-                        .hint
-                        .paint("Update snapshots with `TRYCMD=overwrite`"),
+                    palette.hint("Update snapshots with `TRYCMD=overwrite`"),
                 );
                 let _ = writeln!(
                     stderr,
                     "{}",
-                    palette.hint.paint("Debug output with `TRYCMD=dump`"),
+                    palette.hint("Debug output with `TRYCMD=dump`"),
                 );
                 panic!("{} of {} tests failed", failures.len(), self.cases.len());
             }
@@ -131,7 +127,7 @@ impl Case {
         &self,
         mode: &Mode,
         bins: &crate::BinRegistry,
-        substitutions: &crate::elide::Substitutions,
+        substitutions: &snapbox::Substitutions,
     ) -> Vec<Result<Output, Output>> {
         if self.expected == Some(crate::schema::CommandStatus::Skipped) {
             let output = Output::sequence(self.path.clone());
@@ -159,7 +155,7 @@ impl Case {
             return vec![Ok(output)];
         }
 
-        let fs_context = match crate::FilesystemContext::new(
+        let fs_context = match fs_context(
             &self.path,
             sequence.fs.base.as_deref(),
             sequence.fs.sandbox(),
@@ -178,7 +174,7 @@ impl Case {
             .map(|p| {
                 sequence.fs.rel_cwd().map(|rel| {
                     let p = p.join(rel);
-                    crate::filesystem::strip_trailing_slash(&p).to_owned()
+                    snapbox::path::strip_trailing_slash(&p).to_owned()
                 })
             })
             .transpose()
@@ -203,7 +199,7 @@ impl Case {
         substitutions
             .insert("[EXE]", std::env::consts::EXE_SUFFIX)
             .unwrap();
-        debug!("{:?}", substitutions);
+        snapbox::debug!("{:?}", substitutions);
 
         let mut outputs = Vec::with_capacity(sequence.steps.len());
         let mut prior_step_failed = false;
@@ -213,7 +209,7 @@ impl Case {
             }
 
             let step_status = self.run_step(step, cwd.as_deref(), bins, &substitutions);
-            if fs_context.is_sandbox() && step_status.is_err() && *mode == Mode::Fail {
+            if fs_context.is_mutable() && step_status.is_err() && *mode == Mode::Fail {
                 prior_step_failed = true;
             }
             outputs.push(step_status);
@@ -294,7 +290,7 @@ impl Case {
         step: &mut crate::schema::Step,
         cwd: Option<&std::path::Path>,
         bins: &crate::BinRegistry,
-        substitutions: &crate::elide::Substitutions,
+        substitutions: &snapbox::Substitutions,
     ) -> Result<Output, Output> {
         let output = if let Some(id) = step.id.clone() {
             Output::step(self.path.clone(), id)
@@ -329,7 +325,7 @@ impl Case {
             Some(crate::schema::Bin::Path(_)) => {}
             Some(crate::schema::Bin::Name(name)) => {
                 // Unhandled by resolve
-                debug!("bin={:?} not found", name);
+                snapbox::debug!("bin={:?} not found", name);
                 assert_eq!(output.spawn.status, SpawnStatus::Skipped);
                 return Ok(output);
             }
@@ -338,7 +334,10 @@ impl Case {
             None => {}
         }
 
-        let cmd_output = step.to_output(cwd).map_err(|e| output.clone().error(e))?;
+        let cmd = step.to_command(cwd).map_err(|e| output.clone().error(e))?;
+        let cmd_output = cmd
+            .output()
+            .map_err(|e| output.clone().error(e.to_string().into()))?;
         let output = output.output(cmd_output);
 
         // For Mode::Dump's sake, allow running all
@@ -385,7 +384,7 @@ impl Case {
         &self,
         mut output: Output,
         step: &crate::schema::Step,
-        substitutions: &crate::elide::Substitutions,
+        substitutions: &snapbox::Substitutions,
     ) -> Output {
         output.stdout = self.validate_stream(
             output.stdout,
@@ -406,24 +405,22 @@ impl Case {
     fn validate_stream(
         &self,
         stream: Option<Stream>,
-        expected_content: Option<&crate::File>,
+        expected_content: Option<&crate::Data>,
         binary: bool,
-        substitutions: &crate::elide::Substitutions,
+        substitutions: &snapbox::Substitutions,
     ) -> Option<Stream> {
         let mut stream = stream?;
 
         if !binary {
-            stream = stream.utf8();
+            stream = stream.make_text();
             if !stream.is_ok() {
                 return Some(stream);
             }
         }
 
         if let Some(expected_content) = expected_content {
-            if let crate::File::Text(e) = &expected_content {
-                stream.content = stream
-                    .content
-                    .map_text(|t| crate::elide::normalize(t, e, substitutions));
+            if let Some(e) = expected_content.as_str() {
+                stream.content = stream.content.map_text(|t| substitutions.normalize(t, e));
             }
             if stream.content != *expected_content {
                 stream.status = StreamStatus::Expected(expected_content.clone());
@@ -477,68 +474,34 @@ impl Case {
         actual_root: &std::path::Path,
         mut fs: Filesystem,
         mode: &Mode,
-        substitutions: &crate::elide::Substitutions,
+        substitutions: &snapbox::Substitutions,
     ) -> Result<Filesystem, Filesystem> {
         let mut ok = true;
 
+        #[cfg(feature = "filesystem")]
         if let Mode::Dump(_) = mode {
-            // Handled as part of FilesystemContext
+            // Handled as part of PathFixture
         } else {
             let fixture_root = self.path.with_extension("out");
             if fixture_root.exists() {
-                for expected_path in crate::FsIterate::new(&fixture_root) {
-                    if expected_path
-                        .as_deref()
-                        .map(|p| p.is_dir())
-                        .unwrap_or_default()
-                    {
-                        continue;
-                    }
-
-                    match self.validate_path(
-                        expected_path,
-                        &fixture_root,
-                        actual_root,
-                        substitutions,
-                    ) {
-                        Ok(status) => {
-                            fs.context.push(status);
+                for status in snapbox::path::PathDiff::subset_matches_iter(
+                    actual_root,
+                    fixture_root,
+                    substitutions,
+                ) {
+                    match status {
+                        Ok((expected_path, actual_path)) => {
+                            fs.context.push(FileStatus::Ok {
+                                actual_path,
+                                expected_path,
+                            });
                         }
-                        Err(status) => {
+                        Err(diff) => {
                             let mut is_current_ok = false;
-                            if *mode == Mode::Overwrite {
-                                match &status {
-                                    FileStatus::TypeMismatch {
-                                        expected_path,
-                                        actual_path,
-                                        ..
-                                    } => {
-                                        if crate::shallow_copy(expected_path, actual_path).is_ok() {
-                                            is_current_ok = true;
-                                        }
-                                    }
-                                    FileStatus::LinkMismatch {
-                                        expected_path,
-                                        actual_path,
-                                        ..
-                                    } => {
-                                        if crate::shallow_copy(expected_path, actual_path).is_ok() {
-                                            is_current_ok = true;
-                                        }
-                                    }
-                                    FileStatus::ContentMismatch {
-                                        expected_path,
-                                        actual_content,
-                                        ..
-                                    } => {
-                                        if actual_content.write_to(expected_path).is_ok() {
-                                            is_current_ok = true;
-                                        }
-                                    }
-                                    _ => {}
-                                }
+                            if *mode == Mode::Overwrite && diff.overwrite().is_ok() {
+                                is_current_ok = true;
                             }
-                            fs.context.push(status);
+                            fs.context.push(diff.into());
                             if !is_current_ok {
                                 ok = false;
                             }
@@ -554,96 +517,6 @@ impl Case {
             Err(fs)
         }
     }
-
-    fn validate_path(
-        &self,
-        expected_path: Result<std::path::PathBuf, std::io::Error>,
-        fixture_root: &std::path::Path,
-        actual_root: &std::path::Path,
-        substitutions: &crate::elide::Substitutions,
-    ) -> Result<FileStatus, FileStatus> {
-        let expected_path = expected_path.map_err(|e| FileStatus::Failure(e.to_string().into()))?;
-        let expected_meta = expected_path
-            .symlink_metadata()
-            .map_err(|e| FileStatus::Failure(e.to_string().into()))?;
-        let expected_target = std::fs::read_link(&expected_path).ok();
-
-        let rel = expected_path.strip_prefix(&fixture_root).unwrap();
-        let actual_path = actual_root.join(rel);
-        let actual_meta = actual_path.symlink_metadata().ok();
-        let actual_target = std::fs::read_link(&actual_path).ok();
-
-        let expected_type = if expected_meta.is_dir() {
-            FileType::Dir
-        } else if expected_meta.is_file() {
-            FileType::File
-        } else if expected_target.is_some() {
-            FileType::Symlink
-        } else {
-            FileType::Unknown
-        };
-        let actual_type = if let Some(actual_meta) = actual_meta {
-            if actual_meta.is_dir() {
-                FileType::Dir
-            } else if actual_meta.is_file() {
-                FileType::File
-            } else if actual_target.is_some() {
-                FileType::Symlink
-            } else {
-                FileType::Unknown
-            }
-        } else {
-            FileType::Missing
-        };
-        if expected_type != actual_type {
-            return Err(FileStatus::TypeMismatch {
-                expected_path,
-                actual_path,
-                expected_type,
-                actual_type,
-            });
-        }
-
-        match expected_type {
-            FileType::Symlink => {
-                if expected_target != actual_target {
-                    return Err(FileStatus::LinkMismatch {
-                        expected_path,
-                        actual_path,
-                        expected_target: expected_target.unwrap(),
-                        actual_target: actual_target.unwrap(),
-                    });
-                }
-            }
-            FileType::File => {
-                let expected_content = crate::File::read_from(&expected_path, None)
-                    .map_err(FileStatus::Failure)?
-                    .try_utf8();
-                let mut actual_content = crate::File::read_from(&actual_path, None)
-                    .map_err(FileStatus::Failure)?
-                    .try_utf8();
-
-                if let crate::File::Text(e) = &expected_content {
-                    actual_content =
-                        actual_content.map_text(|t| crate::elide::normalize(t, e, substitutions));
-                }
-                if expected_content != actual_content {
-                    return Err(FileStatus::ContentMismatch {
-                        expected_path,
-                        actual_path,
-                        expected_content,
-                        actual_content,
-                    });
-                }
-            }
-            FileType::Dir | FileType::Unknown | FileType::Missing => {}
-        }
-
-        Ok(FileStatus::Ok {
-            expected_path,
-            actual_path,
-        })
-    }
 }
 
 #[derive(Clone, Debug, PartialEq, Eq)]
@@ -688,12 +561,12 @@ impl Output {
         self.spawn.status = SpawnStatus::Ok;
         self.stdout = Some(Stream {
             stream: Stdio::Stdout,
-            content: crate::File::Binary(output.stdout),
+            content: output.stdout.into(),
             status: StreamStatus::Ok,
         });
         self.stderr = Some(Stream {
             stream: Stdio::Stderr,
-            content: crate::File::Binary(output.stderr),
+            content: output.stderr.into(),
             status: StreamStatus::Ok,
         });
         self
@@ -757,25 +630,25 @@ impl Default for Spawn {
 
 impl std::fmt::Display for Spawn {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        let palette = crate::Palette::current();
+        let palette = snapbox::report::Palette::auto();
 
         match &self.status {
             SpawnStatus::Ok => {
                 if let Some(exit) = self.exit {
                     if exit.success() {
-                        writeln!(f, "Exit: {}", palette.info.paint("success"))?;
+                        writeln!(f, "Exit: {}", palette.info("success"))?;
                     } else if let Some(code) = exit.code() {
-                        writeln!(f, "Exit: {}", palette.error.paint(code))?;
+                        writeln!(f, "Exit: {}", palette.error(code))?;
                     } else {
-                        writeln!(f, "Exit: {}", palette.error.paint("interrupted"))?;
+                        writeln!(f, "Exit: {}", palette.error("interrupted"))?;
                     }
                 }
             }
             SpawnStatus::Skipped => {
-                writeln!(f, "{}", palette.warn.paint("Skipped"))?;
+                writeln!(f, "{}", palette.warn("Skipped"))?;
             }
             SpawnStatus::Failure(msg) => {
-                writeln!(f, "Failed: {}", palette.error.paint(msg))?;
+                writeln!(f, "Failed: {}", palette.error(msg))?;
             }
             SpawnStatus::Expected(expected) => {
                 if let Some(exit) = self.exit {
@@ -783,22 +656,22 @@ impl std::fmt::Display for Spawn {
                         writeln!(
                             f,
                             "Expected {}, was {}",
-                            palette.info.paint(expected),
-                            palette.error.paint("success")
+                            palette.info(expected),
+                            palette.error("success")
                         )?;
                     } else if let Some(code) = exit.code() {
                         writeln!(
                             f,
                             "Expected {}, was {}",
-                            palette.info.paint(expected),
-                            palette.error.paint(code)
+                            palette.info(expected),
+                            palette.error(code)
                         )?;
                     } else {
                         writeln!(
                             f,
                             "Expected {}, was {}",
-                            palette.info.paint(expected),
-                            palette.error.paint("interrupted")
+                            palette.info(expected),
+                            palette.error("interrupted")
                         )?;
                     }
                 }
@@ -826,11 +699,11 @@ impl SpawnStatus {
     }
 
     fn summary(&self) -> impl std::fmt::Display {
-        let palette = crate::Palette::current();
+        let palette = snapbox::report::Palette::auto();
         match self {
-            Self::Ok => palette.info.paint("ok"),
-            Self::Skipped => palette.warn.paint("ignored"),
-            Self::Failure(_) | Self::Expected(_) => palette.error.paint("failed"),
+            Self::Ok => palette.info("ok"),
+            Self::Skipped => palette.warn("ignored"),
+            Self::Failure(_) | Self::Expected(_) => palette.error("failed"),
         }
     }
 }
@@ -838,15 +711,16 @@ impl SpawnStatus {
 #[derive(Clone, Debug, PartialEq, Eq)]
 struct Stream {
     stream: Stdio,
-    content: crate::File,
+    content: crate::Data,
     status: StreamStatus,
 }
 
 impl Stream {
-    fn utf8(mut self) -> Self {
-        if self.content.utf8().is_err() {
+    fn make_text(mut self) -> Self {
+        if self.content.make_text().is_err() {
             self.status = StreamStatus::Failure("invalid UTF-8".into());
         }
+        self.content = self.content.map_text(snapbox::utils::normalize_text);
         self
     }
 
@@ -857,41 +731,31 @@ impl Stream {
 
 impl std::fmt::Display for Stream {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        let palette = crate::Palette::current();
+        let palette = snapbox::report::Palette::auto();
 
         match &self.status {
             StreamStatus::Ok => {
                 writeln!(f, "{}:", self.stream)?;
-                writeln!(f, "{}", palette.info.paint(&self.content))?;
+                writeln!(f, "{}", palette.info(&self.content))?;
             }
             StreamStatus::Failure(msg) => {
                 writeln!(
                     f,
                     "{} {}:",
                     self.stream,
-                    palette.error.paint(format_args!("({})", msg))
+                    palette.error(format_args!("({})", msg))
                 )?;
-                writeln!(f, "{}", palette.info.paint(&self.content))?;
+                writeln!(f, "{}", palette.info(&self.content))?;
             }
             StreamStatus::Expected(expected) => {
-                #[allow(unused_mut)]
-                let mut rendered = false;
-                #[cfg(feature = "diff")]
-                if let (crate::File::Text(expected), crate::File::Text(actual)) =
-                    (&expected, &self.content)
-                {
-                    let diff =
-                        crate::diff::diff(expected, actual, self.stream, self.stream, palette);
-                    writeln!(f, "{}", diff)?;
-                    rendered = true;
-                }
-
-                if !rendered {
-                    writeln!(f, "{} {}:", self.stream, palette.info.paint("(expected)"))?;
-                    writeln!(f, "{}", palette.info.paint(&expected))?;
-                    writeln!(f, "{} {}:", self.stream, palette.error.paint("(actual)"))?;
-                    writeln!(f, "{}", palette.error.paint(&self.content))?;
-                }
+                snapbox::report::write_diff(
+                    f,
+                    expected,
+                    &self.content,
+                    Some(&self.stream),
+                    Some(&self.stream),
+                    palette,
+                )?;
             }
         }
 
@@ -903,7 +767,7 @@ impl std::fmt::Display for Stream {
 enum StreamStatus {
     Ok,
     Failure(crate::Error),
-    Expected(crate::File),
+    Expected(crate::Data),
 }
 
 impl StreamStatus {
@@ -983,8 +847,8 @@ enum FileStatus {
     ContentMismatch {
         expected_path: std::path::PathBuf,
         actual_path: std::path::PathBuf,
-        expected_content: crate::File,
-        actual_content: crate::File,
+        expected_content: crate::Data,
+        actual_content: crate::Data,
     },
 }
 
@@ -1000,12 +864,53 @@ impl FileStatus {
     }
 }
 
+impl From<snapbox::path::PathDiff> for FileStatus {
+    fn from(other: snapbox::path::PathDiff) -> Self {
+        match other {
+            snapbox::path::PathDiff::Failure(err) => FileStatus::Failure(err),
+            snapbox::path::PathDiff::TypeMismatch {
+                expected_path,
+                actual_path,
+                expected_type,
+                actual_type,
+            } => FileStatus::TypeMismatch {
+                actual_path,
+                expected_path,
+                actual_type,
+                expected_type,
+            },
+            snapbox::path::PathDiff::LinkMismatch {
+                expected_path,
+                actual_path,
+                expected_target,
+                actual_target,
+            } => FileStatus::LinkMismatch {
+                actual_path,
+                expected_path,
+                actual_target,
+                expected_target,
+            },
+            snapbox::path::PathDiff::ContentMismatch {
+                expected_path,
+                actual_path,
+                expected_content,
+                actual_content,
+            } => FileStatus::ContentMismatch {
+                actual_path,
+                expected_path,
+                actual_content,
+                expected_content,
+            },
+        }
+    }
+}
+
 impl std::fmt::Display for FileStatus {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        let palette = crate::Palette::current();
+        let palette = snapbox::report::Palette::auto();
 
         match &self {
-            FileStatus::Ok {
+            Self::Ok {
                 expected_path,
                 actual_path: _actual_path,
             } => {
@@ -1013,13 +918,13 @@ impl std::fmt::Display for FileStatus {
                     f,
                     "{}: is {}",
                     expected_path.display(),
-                    palette.info.paint("good"),
+                    palette.info("good"),
                 )?;
             }
-            FileStatus::Failure(msg) => {
-                writeln!(f, "{}", palette.error.paint(msg))?;
+            Self::Failure(msg) => {
+                writeln!(f, "{}", palette.error(msg))?;
             }
-            FileStatus::TypeMismatch {
+            Self::TypeMismatch {
                 expected_path,
                 actual_path: _actual_path,
                 expected_type,
@@ -1029,11 +934,11 @@ impl std::fmt::Display for FileStatus {
                     f,
                     "{}: Expected {}, was {}",
                     expected_path.display(),
-                    palette.info.paint(expected_type),
-                    palette.error.paint(actual_type)
+                    palette.info(expected_type),
+                    palette.error(actual_type)
                 )?;
             }
-            FileStatus::LinkMismatch {
+            Self::LinkMismatch {
                 expected_path,
                 actual_path: _actual_path,
                 expected_target,
@@ -1043,49 +948,24 @@ impl std::fmt::Display for FileStatus {
                     f,
                     "{}: Expected {}, was {}",
                     expected_path.display(),
-                    palette.info.paint(expected_target.display()),
-                    palette.error.paint(actual_target.display())
+                    palette.info(expected_target.display()),
+                    palette.error(actual_target.display())
                 )?;
             }
-            FileStatus::ContentMismatch {
+            Self::ContentMismatch {
                 expected_path,
                 actual_path,
                 expected_content,
                 actual_content,
             } => {
-                #[allow(unused_mut)]
-                let mut rendered = false;
-                #[cfg(feature = "diff")]
-                if let (crate::File::Text(expected), crate::File::Text(actual)) =
-                    (&expected_content, &actual_content)
-                {
-                    let diff = crate::diff::diff(
-                        expected,
-                        actual,
-                        expected_path.display(),
-                        actual_path.display(),
-                        palette,
-                    );
-                    writeln!(f, "{}", diff)?;
-                    rendered = true;
-                }
-
-                if !rendered {
-                    writeln!(
-                        f,
-                        "{} {}:",
-                        expected_path.display(),
-                        palette.info.paint("(expected)")
-                    )?;
-                    writeln!(f, "{}", palette.info.paint(&expected_content))?;
-                    writeln!(
-                        f,
-                        "{} {}:",
-                        actual_path.display(),
-                        palette.error.paint("(actual)")
-                    )?;
-                    writeln!(f, "{}", palette.error.paint(&actual_content))?;
-                }
+                snapbox::report::write_diff(
+                    f,
+                    expected_content,
+                    actual_content,
+                    Some(&expected_path.display()),
+                    Some(&actual_path.display()),
+                    palette,
+                )?;
             }
         }
 
@@ -1093,33 +973,6 @@ impl std::fmt::Display for FileStatus {
     }
 }
 
-#[derive(Clone, Debug, PartialEq, Eq)]
-pub(crate) enum FileType {
-    Dir,
-    File,
-    Symlink,
-    Unknown,
-    Missing,
-}
-
-impl FileType {
-    fn as_str(&self) -> &str {
-        match self {
-            Self::Dir => "dir",
-            Self::File => "file",
-            Self::Symlink => "symlink",
-            Self::Unknown => "unknown",
-            Self::Missing => "missing",
-        }
-    }
-}
-
-impl std::fmt::Display for FileType {
-    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        self.as_str().fmt(f)
-    }
-}
-
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub(crate) enum Mode {
     Fail,
@@ -1142,3 +995,38 @@ impl Mode {
         Ok(())
     }
 }
+
+#[cfg_attr(not(feature = "filesystem"), allow(unused_variables))]
+fn fs_context(
+    path: &std::path::Path,
+    cwd: Option<&std::path::Path>,
+    sandbox: bool,
+    mode: &crate::Mode,
+) -> Result<snapbox::path::PathFixture, crate::Error> {
+    if sandbox {
+        #[cfg(feature = "filesystem")]
+        match mode {
+            crate::Mode::Dump(root) => {
+                let target = root.join(path.with_extension("out").file_name().unwrap());
+                let mut context = snapbox::path::PathFixture::mutable_at(&target)?;
+                if let Some(cwd) = cwd {
+                    context = context.with_template(cwd)?;
+                }
+                Ok(context)
+            }
+            crate::Mode::Fail | crate::Mode::Overwrite => {
+                let mut context = snapbox::path::PathFixture::mutable_temp()?;
+                if let Some(cwd) = cwd {
+                    context = context.with_template(cwd)?;
+                }
+                Ok(context)
+            }
+        }
+        #[cfg(not(feature = "filesystem"))]
+        Err("Sandboxing is disabled".into())
+    } else {
+        Ok(cwd
+            .map(snapbox::path::PathFixture::immutable)
+            .unwrap_or_else(snapbox::path::PathFixture::none))
+    }
+}
